StatFunctions

Struct StatFunctions 

pub struct StatFunctions { /* private fields */ }
Statistical functions for DataFrames.

Mirrors pyspark.sql.DataFrameStatFunctions.

Implementations

Source

impl StatFunctions

pub fn crosstab(&self, col1: &str, col2: &str) -> DataFrame

Compute a cross-tabulation of two columns.

pub fn freq_items(&self, columns: Vec<&str>, support: f64) -> DataFrame

Find frequent items.

pub fn approx_quantile( &self, columns: Vec<&str>, probabilities: Vec<f64>, relative_error: f64, ) -> DataFrame

Compute approximate quantiles.

pub fn corr(&self, col1: &str, col2: &str) -> Result<f64>

Compute correlation between two columns.

Executes the stat aggregation and returns the resulting f64 (NaN when the correlation is undefined, e.g. an empty relation).

pub fn cov(&self, col1: &str, col2: &str) -> Result<f64>

Compute covariance between two columns.

Executes the stat aggregation and returns the resulting f64.

pub fn sample_by( &self, col: &str, fractions: Vec<(Expression, f64)>, seed: Option<i64>, ) -> DataFrame

Sample by values in a column.