pub enum Command {
Status(bool),
LastProgress(bool),
RecentProgress(bool),
Stop(bool),
ProcessAllAvailable(bool),
Explain(ExplainCommand),
Exception(bool),
AwaitTermination(AwaitTerminationCommand),
}Expand description
See documentation for the corresponding API method in StreamingQuery.
Variants
Status(bool)
status() API.
LastProgress(bool)
lastProgress() API.
RecentProgress(bool)
recentProgress() API.
Stop(bool)
stop() API. Stops the query.
ProcessAllAvailable(bool)
processAllAvailable() API. Waits till all the available data is processed
Explain(ExplainCommand)
explain() API. Returns logical and physical plans.
Exception(bool)
exception() API. Returns the exception in the query if any.
AwaitTermination(AwaitTerminationCommand)
awaitTermination() API. Waits for the termination of the query.
Implementations
Sourceimpl Command
impl Command
Sourcepub fn merge(
field: &mut Option<Command>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Command>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.