InterruptRequest

Struct InterruptRequest 

pub struct InterruptRequest {
    pub session_id: String,
    pub user_context: Option<UserContext>,
    pub client_type: Option<String>,
    pub interrupt_type: i32,
    pub interrupt: Option<Interrupt>,
}

Fields

session_id: String

(Required)

The session_id specifies a spark session for a user id (which is specified by user_context.user_id). The session_id is set by the client to be able to collate streaming responses from different queries within the dedicated session. The id should be an UUID string of the format 00112233-4455-6677-8899-aabbccddeeff

user_context: Option<UserContext>

(Required) User context

client_type: Option<String>

Provides optional information about the client sending the request. This field can be used for language or version specific information and is only intended for logging purposes and will not be interpreted by the server.

interrupt_type: i32

(Required) The type of interrupt to execute.

interrupt: Option<Interrupt>

Implementations

Source

impl InterruptRequest

pub fn client_type(&self) -> &str

Returns the value of client_type, or the default value if client_type is unset.

pub fn interrupt_type(&self) -> InterruptType

Returns the enum value of interrupt_type, or the default if the field is set to an invalid enum value.

pub fn set_interrupt_type(&mut self, value: InterruptType)

Sets interrupt_type to the provided enum value.