pub struct Sample {
pub input: Option<Box<Relation>>,
pub lower_bound: f64,
pub upper_bound: f64,
pub with_replacement: Option<bool>,
pub seed: Option<i64>,
pub deterministic_order: bool,
}Expand description
Relation of type Sample that samples a fraction of the dataset.
Fields
input: Option<Box<Relation>>(Required) Input relation for a Sample.
lower_bound: f64(Required) lower bound.
upper_bound: f64(Required) upper bound.
with_replacement: Option<bool>(Optional) Whether to sample with replacement.
seed: Option<i64>(Optional) The random seed.
deterministic_order: bool(Required) Explicitly sort the underlying plan to make the ordering deterministic or cache it.
This flag is true when invoking dataframe.randomSplit to randomly splits DataFrame with the
provided weights. Otherwise, it is false.
Implementations