pub struct StatFreqItems {
pub input: Option<Box<Relation>>,
pub cols: Vec<String>,
pub support: Option<f64>,
}Expand description
Finding frequent items for columns, possibly with false positives. It will invoke ‘Dataset.stat.freqItems’ (same as ‘StatFunctions.freqItems’) to compute the results.
Fields
input: Option<Box<Relation>>(Required) The input relation.
cols: Vec<String>(Required) The names of the columns to search frequent items in.
support: Option<f64>(Optional) The minimum frequency for an item to be considered frequent.
Should be greater than 1e-4.
Implementations