pub enum SaveType {
Path(String),
Table(SaveTable),
}Expand description
(Optional)
The destination of the write operation can be either a path or a table.
If the destination is neither a path nor a table, such as jdbc and noop,
the save_type should not be set.
Variants
Implementations
Sourceimpl SaveType
impl SaveType
Sourcepub fn merge(
field: &mut Option<SaveType>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<SaveType>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.