DataStreamWriter

Struct DataStreamWriter 

pub struct DataStreamWriter { /* private fields */ }
DataStreamWriter for writing streaming data to various sinks.

Mirrors pyspark.sql.connect.streaming.DataStreamWriter.

Implementations

Source

impl DataStreamWriter

pub fn output_mode(self, mode: &str) -> Self

Set the output mode (“append”, “update”, “complete”).

pub fn format(self, source: &str) -> Self

Set the format/sink type (e.g., “parquet”, “json”, “csv”, “console”, “noop”, “kafka”).

pub fn option(self, key: &str, value: &str) -> Self

Set a single option key-value pair.

pub fn options(self, options: HashMap<String, String>) -> Self

Set multiple options.

pub fn partition_by(self, columns: Vec<&str>) -> Self

Set partitioning columns.

pub fn cluster_by(self, columns: Vec<&str>) -> Self

Set clustering columns.

pub fn query_name(self, name: &str) -> Self

Set the query name.

pub fn trigger(self, trigger: Trigger) -> Self

Set the trigger type.

pub fn foreach_batch(self, payload: PythonUDFPayload) -> Self

Set a foreach batch function (PythonUDF payload).

pub fn foreach(self, payload: PythonUDFPayload) -> Self

Set a foreach function (PythonUDF payload).

pub fn start(self, path: &str) -> Result<StreamingQuery>

Start the streaming query writing to a path, returning a StreamingQuery handle.

pub fn to_table(self, table_name: &str) -> Result<StreamingQuery>

Start the streaming query writing to a table, returning a StreamingQuery handle.