pub struct StreamingQuery { /* private fields */ }Expand description
A handle to an active streaming query.
Mirrors pyspark.sql.connect.streaming.StreamingQuery.
Implementations
Sourceimpl StreamingQuery
impl StreamingQuery
Sourcepub fn status(&self) -> Result<StreamingQueryStatus>
pub fn status(&self) -> Result<StreamingQueryStatus>
Get the current status of the query.
Sourcepub fn await_termination(
&self,
timeout_sec: Option<f64>,
) -> Result<Option<bool>>
pub fn await_termination( &self, timeout_sec: Option<f64>, ) -> Result<Option<bool>>
Wait for the query to terminate with optional timeout in seconds.
Sourcepub fn last_progress(&self) -> Result<Option<String>>
pub fn last_progress(&self) -> Result<Option<String>>
Get the last streaming progress, if available.
Sourcepub fn recent_progress(&self) -> Result<Vec<String>>
pub fn recent_progress(&self) -> Result<Vec<String>>
Get recent streaming progress results.
Sourcepub fn process_all_available(&self) -> Result<()>
pub fn process_all_available(&self) -> Result<()>
Process all available data in the streaming query.
Sourcepub fn explain(&self, extended: bool) -> Result<String>
pub fn explain(&self, extended: bool) -> Result<String>
Print the execution plan of the streaming query.
Sourcepub fn exception(&self) -> Result<Option<StreamingQueryException>>
pub fn exception(&self) -> Result<Option<StreamingQueryException>>
Get any exception that occurred in the streaming query.