pub struct WindowSpec {
pub partition_spec: Vec<Expression>,
pub order_spec: Vec<SortOrder>,
pub frame_spec: Option<(FrameType, FrameBound, FrameBound)>,
}Expand description
pyspark.sql.window.WindowSpec
Represents a complete window specification with optional partition, order, and frame specs.
This is built using the static builder methods on Window or by chaining methods on this struct.
Fields
partition_spec: Vec<Expression>Expressions to partition by.
order_spec: Vec<SortOrder>Sort orders for the window.
frame_spec: Option<(FrameType, FrameBound, FrameBound)>Optional window frame specification.
Implementations
Sourceimpl WindowSpec
impl WindowSpec
Sourcepub fn partition_by(self, cols: Vec<Expression>) -> Self
pub fn partition_by(self, cols: Vec<Expression>) -> Self
Add partition columns to this window specification.
Sourcepub fn order_by(self, sorts: Vec<SortOrder>) -> Self
pub fn order_by(self, sorts: Vec<SortOrder>) -> Self
Set ordering for this window specification.
Sourcepub fn rows_between(self, start: FrameBound, end: FrameBound) -> Self
pub fn rows_between(self, start: FrameBound, end: FrameBound) -> Self
Set the frame specification for ROWS.
Sourcepub fn range_between(self, start: FrameBound, end: FrameBound) -> Self
pub fn range_between(self, start: FrameBound, end: FrameBound) -> Self
Set the frame specification for RANGE.