pub struct DataFrameWriterV2 { /* private fields */ }Expand description
DataFrameWriterV2 for the v2 write API (DataFrame.writeTo).
Mirrors pyspark.sql.connect.readwriter.DataFrameWriterV2.
Implementations
Sourceimpl DataFrameWriterV2
impl DataFrameWriterV2
Sourcepub fn cluster_by<S: Into<String>>(
self,
cols: impl IntoIterator<Item = S>,
) -> Self
pub fn cluster_by<S: Into<String>>( self, cols: impl IntoIterator<Item = S>, ) -> Self
Cluster the output table by the given columns (liquid clustering).
Sourcepub fn using(self, provider: &str) -> Self
pub fn using(self, provider: &str) -> Self
Specify the underlying output data source provider (e.g. “parquet”).
Sourcepub fn table_property(self, property: &str, value: &str) -> Self
pub fn table_property(self, property: &str, value: &str) -> Self
Add a table property.
Sourcepub fn partition_by<C: Into<Column>>(
self,
columns: impl IntoIterator<Item = C>,
) -> Self
pub fn partition_by<C: Into<Column>>( self, columns: impl IntoIterator<Item = C>, ) -> Self
Partition the output table by the given columns.
Sourcepub fn create_or_replace(self) -> Result<()>
pub fn create_or_replace(self) -> Result<()>
Create the table, or replace it if it already exists.
Sourcepub fn overwrite(self, condition: Column) -> Result<()>
pub fn overwrite(self, condition: Column) -> Result<()>
Overwrite rows matching condition with the DataFrame’s rows.
Sourcepub fn overwrite_partitions(self) -> Result<()>
pub fn overwrite_partitions(self) -> Result<()>
Overwrite all partitions touched by the DataFrame (dynamic overwrite).