pub struct DataStreamWriter { /* private fields */ }Expand description
DataStreamWriter for writing streaming data to various sinks.
Mirrors pyspark.sql.connect.streaming.DataStreamWriter.
Implementations
Sourceimpl DataStreamWriter
impl DataStreamWriter
Sourcepub fn output_mode(self, mode: &str) -> Self
pub fn output_mode(self, mode: &str) -> Self
Set the output mode (“append”, “update”, “complete”).
Sourcepub fn format(self, source: &str) -> Self
pub fn format(self, source: &str) -> Self
Set the format/sink type (e.g., “parquet”, “json”, “csv”, “console”, “noop”, “kafka”).
Sourcepub fn partition_by(self, columns: Vec<&str>) -> Self
pub fn partition_by(self, columns: Vec<&str>) -> Self
Set partitioning columns.
Sourcepub fn cluster_by(self, columns: Vec<&str>) -> Self
pub fn cluster_by(self, columns: Vec<&str>) -> Self
Set clustering columns.
Sourcepub fn query_name(self, name: &str) -> Self
pub fn query_name(self, name: &str) -> Self
Set the query name.
Sourcepub fn foreach_batch(self, payload: PythonUDFPayload) -> Self
pub fn foreach_batch(self, payload: PythonUDFPayload) -> Self
Set a foreach batch function (PythonUDF payload).
Sourcepub fn foreach(self, payload: PythonUDFPayload) -> Self
pub fn foreach(self, payload: PythonUDFPayload) -> Self
Set a foreach function (PythonUDF payload).
Sourcepub fn start(self, path: &str) -> Result<StreamingQuery>
pub fn start(self, path: &str) -> Result<StreamingQuery>
Start the streaming query writing to a path, returning a StreamingQuery handle.
Sourcepub fn to_table(self, table_name: &str) -> Result<StreamingQuery>
pub fn to_table(self, table_name: &str) -> Result<StreamingQuery>
Start the streaming query writing to a table, returning a StreamingQuery handle.